@@ -25,7 +25,7 @@
  */
 class CFrontendSetup {
 
-	const MIN_PHP_VERSION = '5.4.0';
+	const MIN_PHP_VERSION = '7.2.0';
 	const MIN_PHP_MEMORY_LIMIT = '134217728'; // 128 * ZBX_MEBIBYTE;
 	const MIN_PHP_POST_MAX_SIZE = '16777216'; // 16 * ZBX_MEBIBYTE;
 	const MIN_PHP_UPLOAD_MAX_FILESIZE = '2097152'; // 2 * ZBX_MEBIBYTE;
@@ -71,11 +71,6 @@ class CFrontendSetup {
 		if (extension_loaded('mbstring')) {
 			$result[] = $this->checkPhpMbstringFuncOverload();
 		}
-
-		// check for deprecated PHP 5.6.0 option 'always_populate_raw_post_data'
-		if (version_compare(PHP_VERSION, '5.6', '>=') && version_compare(PHP_VERSION, '7.0', '<')) {
-			$result[] = $this->checkPhpAlwaysPopulateRawPostData();
-		}
 		$result[] = $this->checkPhpSockets();
 		$result[] = $this->checkPhpGd();
 		$result[] = $this->checkPhpGdPng();
@@ -86,6 +81,7 @@ class CFrontendSetup {
 		$result[] = $this->checkPhpXmlWriter();
 		$result[] = $this->checkPhpXmlReader();
 		$result[] = $this->checkPhpLdapModule();
+		$result[] = $this->checkPhpOpenSsl();
 		$result[] = $this->checkPhpCtype();
 		$result[] = $this->checkPhpSession();
 		$result[] = $this->checkPhpSessionAutoStart();
@@ -101,14 +97,14 @@ class CFrontendSetup {
 	 * @return array
 	 */
 	public function checkPhpVersion() {
-		$check = version_compare(phpversion(), self::MIN_PHP_VERSION, '>=');
+		$check = version_compare(PHP_VERSION, self::MIN_PHP_VERSION, '>=');
 
 		return [
 			'name' => _('PHP version'),
-			'current' => phpversion(),
+			'current' => PHP_VERSION,
 			'required' => self::MIN_PHP_VERSION,
 			'result' => $check ? self::CHECK_OK : self::CHECK_FATAL,
-			'error' => _s('Minimum required PHP version is %s.', self::MIN_PHP_VERSION)
+			'error' => _s('Minimum required PHP version is %1$s.', self::MIN_PHP_VERSION)
 		];
 	}
 
@@ -126,8 +122,9 @@ class CFrontendSetup {
 			'current' => $current,
 			'required' => mem2str(self::MIN_PHP_MEMORY_LIMIT),
 			'result' => $check ? self::CHECK_OK : self::CHECK_FATAL,
-			'error' => _s('Minimum required PHP memory limit is %s (configuration option "memory_limit").',
-				mem2str(self::MIN_PHP_MEMORY_LIMIT))
+			'error' => _s('Minimum required PHP memory limit is %1$s (configuration option "memory_limit").',
+				mem2str(self::MIN_PHP_MEMORY_LIMIT)
+			)
 		];
 	}
 
@@ -144,8 +141,9 @@ class CFrontendSetup {
 			'current' => $current,
 			'required' => mem2str(self::MIN_PHP_POST_MAX_SIZE),
 			'result' => (str2mem($current) >= self::MIN_PHP_POST_MAX_SIZE) ? self::CHECK_OK : self::CHECK_FATAL,
-			'error' => _s('Minimum required size of PHP post is %s (configuration option "post_max_size").',
-				mem2str(self::MIN_PHP_POST_MAX_SIZE))
+			'error' => _s('Minimum required size of PHP post is %1$s (configuration option "post_max_size").',
+				mem2str(self::MIN_PHP_POST_MAX_SIZE)
+			)
 		];
 	}
 
@@ -162,8 +160,9 @@ class CFrontendSetup {
 			'current' => $current,
 			'required' => mem2str(self::MIN_PHP_UPLOAD_MAX_FILESIZE),
 			'result' => (str2mem($current) >= self::MIN_PHP_UPLOAD_MAX_FILESIZE) ? self::CHECK_OK : self::CHECK_FATAL,
-			'error' => _s('Minimum required PHP upload filesize is %s (configuration option "upload_max_filesize").',
-				mem2str(self::MIN_PHP_UPLOAD_MAX_FILESIZE))
+			'error' => _s('Minimum required PHP upload filesize is %1$s (configuration option "upload_max_filesize").',
+				mem2str(self::MIN_PHP_UPLOAD_MAX_FILESIZE)
+			)
 		];
 	}
 
@@ -192,7 +191,9 @@ class CFrontendSetup {
 			'current' => $current,
 			'required' => self::MIN_PHP_MAX_EXECUTION_TIME,
 			'result' => $currentIsValid ? self::CHECK_OK : self::CHECK_FATAL,
-			'error' => _s('Minimum required limit on execution time of PHP scripts is %s (configuration option "max_execution_time").', self::MIN_PHP_MAX_EXECUTION_TIME)
+			'error' => _s('Minimum required limit on execution time of PHP scripts is %1$s (configuration option "max_execution_time").',
+				self::MIN_PHP_MAX_EXECUTION_TIME
+			)
 		];
 	}
 
@@ -213,7 +214,9 @@ class CFrontendSetup {
 			'current' => $current,
 			'required' => self::MIN_PHP_MAX_INPUT_TIME,
 			'result' => $currentIsValid ? self::CHECK_OK : self::CHECK_FATAL,
-			'error' => _s('Minimum required limit on input parse time for PHP scripts is %s (configuration option "max_input_time").', self::MIN_PHP_MAX_INPUT_TIME)
+			'error' => _s('Minimum required limit on input parse time for PHP scripts is %1$s (configuration option "max_input_time").',
+				self::MIN_PHP_MAX_INPUT_TIME
+			)
 		];
 	}
 
@@ -253,7 +256,7 @@ class CFrontendSetup {
 			'current' => empty($current) ? _('off') : new CSpan($current),
 			'required' => null,
 			'result' => $current ? self::CHECK_OK : self::CHECK_FATAL,
-			'error' => _('At least one of MySQL, PostgreSQL, Oracle or IBM DB2 should be supported.')
+			'error' => _('At least one of MySQL, PostgreSQL or Oracle should be supported.')
 		];
 	}
 
@@ -281,12 +284,6 @@ class CFrontendSetup {
 			$allowed_db[ZBX_DB_ORACLE] = 'Oracle';
 		}
 
-		if (zbx_is_callable(['db2_autocommit', 'db2_bind_param', 'db2_close', 'db2_commit', 'db2_conn_errormsg',
-				'db2_connect', 'db2_escape_string', 'db2_execute', 'db2_fetch_assoc', 'db2_free_result', 'db2_prepare',
-				'db2_rollback', 'db2_set_option', 'db2_stmt_errormsg'])) {
-			$allowed_db[ZBX_DB_DB2] = 'IBM DB2';
-		}
-
 		return $allowed_db;
 	}
 
@@ -354,27 +351,6 @@ class CFrontendSetup {
 		];
 	}
 
-	/**
-	 * Checks for PHP option always_populate_raw_post_data. As of PHP version 5.6.0 this option is deprecated.
-	 * In case this option is not set or is enabled, PHP will throw E_DEPRECATED error. This option should be set to -1
-	 * ini php.ini and cannot be set at runtime.
-	 *
-	 * See: http://php.net/manual/en/ini.core.php#ini.always-populate-raw-post-data
-	 *
-	 * @return array
-	 */
-	public function checkPhpAlwaysPopulateRawPostData() {
-		$current = ini_get('always_populate_raw_post_data');
-
-		return [
-			'name' => _s('PHP option "%1$s"', 'always_populate_raw_post_data'),
-			'current' => ($current != -1) ? _('on') : _('off'),
-			'required' => _('off'),
-			'result' => ($current != -1) ? self::CHECK_FATAL : self::CHECK_OK,
-			'error' => _s('PHP option "%1$s" must be set to "%2$s"', 'always_populate_raw_post_data', -1)
-		];
-	}
-
 	/**
 	 * Checks for PHP sockets extension.
 	 *
@@ -447,10 +423,8 @@ class CFrontendSetup {
 	 */
 	public function checkPhpGdJpeg() {
 		if (is_callable('gd_info')) {
-			$gdInfo = gd_info();
-
-			// check for PHP prior 5.3.0, it returns 'JPG Support' key.
-			$current = isset($gdInfo['JPG Support']) ? $gdInfo['JPG Support'] : $gdInfo['JPEG Support'];
+			$gd_info = gd_info();
+			$current = $gd_info['JPEG Support'];
 		}
 		else {
 			$current = false;
@@ -579,6 +553,23 @@ class CFrontendSetup {
 		];
 	}
 
+	/**
+	 * Checks for PHP OpenSSL extension.
+	 *
+	 * @return array
+	 */
+	public function checkPhpOpenSsl() {
+		$current = extension_loaded('openssl');
+
+		return [
+			'name' => _('PHP OpenSSL'),
+			'current' => $current ? _('on') : _('off'),
+			'required' => null,
+			'result' => $current ? self::CHECK_OK : self::CHECK_WARNING,
+			'error' => _('PHP OpenSSL extension missing.')
+		];
+	}
+
 	/**
 	 * Checks for PHP ctype extension.
 	 *
@@ -675,4 +666,28 @@ class CFrontendSetup {
 			)
 		];
 	}
+
+	/**
+	 * Checks for the SSL parameters point to files that are open for writing.
+	 *
+	 * @return array
+	 */
+	public function checkSslFiles() {
+		global $DB;
+		$writeable = [];
+
+		foreach (['KEY_FILE', 'CERT_FILE', 'CA_FILE'] as $key) {
+			if ($DB[$key] !== '' && is_writable($DB[$key])) {
+				$writeable[] = $key;
+			}
+		}
+
+		return [
+			'name' => _('TLS certificate file'),
+			'current' => implode(', ', $writeable),
+			'required' => null,
+			'result' => $writeable ? self::CHECK_FATAL : self::CHECK_OK,
+			'error' => _s('TLS certificate files must be read-only')
+		];
+	}
 }
