@@ -33,7 +33,7 @@ function prepareSubfilterOutput($label, $data, $subfilter, $subfilterName) {
 				(new CLinkAction($element['name']))
 					->onClick(CHtml::encode(
 						'javascript: create_var("zbx_filter", "subfilter_set", "1", false);'.
-						'create_var("zbx_filter", '.CJs::encodeJson($subfilterName.'['.$id.']').', null, true);'
+						'create_var("zbx_filter", '.json_encode($subfilterName.'['.$id.']').', null, true);'
 					)),
 				' ',
 				new CSup($element['count'])
@@ -57,8 +57,8 @@ function prepareSubfilterOutput($label, $data, $subfilter, $subfilterName) {
 					->onClick(CHtml::encode(
 						'javascript: create_var("zbx_filter", "subfilter_set", "1", false);'.
 						'create_var("zbx_filter", '.
-							CJs::encodeJson($subfilterName.'['.$id.']').', '.
-							CJs::encodeJson($id).', '.
+							json_encode($subfilterName.'['.$id.']').', '.
+							json_encode($id).', '.
 							'true'.
 						');'
 					));
@@ -84,10 +84,7 @@ function getItemFilterForm(&$items) {
 	$filter_name				= $_REQUEST['filter_name'];
 	$filter_type				= $_REQUEST['filter_type'];
 	$filter_key					= $_REQUEST['filter_key'];
-	$filter_snmp_community		= $_REQUEST['filter_snmp_community'];
-	$filter_snmpv3_securityname	= $_REQUEST['filter_snmpv3_securityname'];
 	$filter_snmp_oid			= $_REQUEST['filter_snmp_oid'];
-	$filter_port				= $_REQUEST['filter_port'];
 	$filter_value_type			= $_REQUEST['filter_value_type'];
 	$filter_delay				= $_REQUEST['filter_delay'];
 	$filter_history				= $_REQUEST['filter_history'];
@@ -145,20 +142,8 @@ function getItemFilterForm(&$items) {
 		if ($type != ITEM_TYPE_TRAPPER && $type != ITEM_TYPE_SNMPTRAP) {
 			zbx_subarray_push($fTypeVisibility, $type, 'filter_delay_row');
 		}
-
-		switch ($type) {
-			case ITEM_TYPE_SNMPV1:
-			case ITEM_TYPE_SNMPV2C:
-				zbx_subarray_push($fTypeVisibility, $type, 'filter_snmp_community_row');
-				zbx_subarray_push($fTypeVisibility, $type, 'filter_snmp_oid_row');
-				zbx_subarray_push($fTypeVisibility, $type, 'filter_port_row');
-				break;
-
-			case ITEM_TYPE_SNMPV3:
-				zbx_subarray_push($fTypeVisibility, $type, 'filter_snmpv3_securityname_row');
-				zbx_subarray_push($fTypeVisibility, $type, 'filter_snmp_oid_row');
-				zbx_subarray_push($fTypeVisibility, $type, 'filter_port_row');
-				break;
+		if ($type == ITEM_TYPE_SNMP) {
+			zbx_subarray_push($fTypeVisibility, $type, 'filter_snmp_oid_row');
 		}
 	}
 
@@ -222,16 +207,18 @@ function getItemFilterForm(&$items) {
 	$filterColumn1->addRow((new CLabel(_('Hosts'), 'filter_hostid_ms')),
 		(new CMultiSelect([
 			'name' => 'filter_hostids[]',
-			'object_name' => 'hosts',
+			'object_name' => 'host_templates',
 			'data' => $host_filter,
 			'popup' => [
+				'filter_preselect_fields' => [
+					'hostgroups' => 'filter_groupids_'
+				],
 				'parameters' => [
 					'srctbl' => 'host_templates',
 					'srcfld1' => 'hostid',
 					'dstfrm' => $filter->getName(),
 					'dstfld1' => 'filter_hostids_',
-					'editable' => true,
-					'templated_hosts' => true
+					'editable' => true
 				]
 			]
 		]))->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH)
@@ -257,29 +244,17 @@ function getItemFilterForm(&$items) {
 			(new CButton(null, _('Select')))
 				->addClass(ZBX_STYLE_BTN_GREY)
 				->onClick('return PopUp("popup.generic",jQuery.extend('.
-					CJs::encodeJson([
+					json_encode([
 						'srctbl' => 'applications',
 						'srcfld1' => 'name',
 						'dstfrm' => $filter->getName(),
 						'dstfld1' => 'filter_application',
 						'with_applications' => '1'
 					]).
-					',(jQuery("input[name=\'filter_hostids\']").length > 0)'.
-						' ? {hostid: jQuery("input[name=\'filter_hostids\']").val()}'.
-						' : {}'.
-					'), null, this);'
+					', getFirstMultiselectValue("filter_hostids_")), null, this);'
 				)
 		]
 	);
-	$filterColumn2->addRow(_('SNMP community'),
-		(new CTextBox('filter_snmp_community', $filter_snmp_community))->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH),
-		'filter_snmp_community_row'
-	);
-	$filterColumn2->addRow(_('Security name'),
-		(new CTextBox('filter_snmpv3_securityname', $filter_snmpv3_securityname))
-			->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH),
-		'filter_snmpv3_securityname_row'
-	);
 
 	$filterColumn3->addRow(_('History'),
 		(new CTextBox('filter_history', $filter_history))->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH)
@@ -315,10 +290,6 @@ function getItemFilterForm(&$items) {
 	$filterColumn1->addRow(_('Key'),
 		(new CTextBox('filter_key', $filter_key))->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH)
 	);
-	$filterColumn2->addRow(_('Port'),
-		(new CNumericBox('filter_port', $filter_port, 5, false, true))->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH),
-		'filter_port_row'
-	);
 	$filterColumn4->addRow(_('Discovery'),
 		new CComboBox('filter_discovery', $filter_discovery, null, [
 			-1 => _('all'),
@@ -811,9 +782,7 @@ function getItemFormData(array $item = [], array $options = []) {
 		'history' => getRequest('history', DB::getDefault('items', 'history')),
 		'status' => getRequest('status', isset($_REQUEST['form_refresh']) ? 1 : 0),
 		'type' => getRequest('type', 0),
-		'snmp_community' => getRequest('snmp_community', 'public'),
 		'snmp_oid' => getRequest('snmp_oid', ''),
-		'port' => getRequest('port', ''),
 		'value_type' => getRequest('value_type', ITEM_VALUE_TYPE_UINT64),
 		'trapper_hosts' => getRequest('trapper_hosts', ''),
 		'units' => getRequest('units', ''),
@@ -823,13 +792,6 @@ function getItemFormData(array $item = [], array $options = []) {
 		'new_application' => getRequest('new_application', ''),
 		'applications' => getRequest('applications', []),
 		'delay_flex' => array_values(getRequest('delay_flex', [])),
-		'snmpv3_contextname' => getRequest('snmpv3_contextname', ''),
-		'snmpv3_securityname' => getRequest('snmpv3_securityname', ''),
-		'snmpv3_securitylevel' => getRequest('snmpv3_securitylevel', 0),
-		'snmpv3_authprotocol' => getRequest('snmpv3_authprotocol', ITEM_AUTHPROTOCOL_MD5),
-		'snmpv3_authpassphrase' => getRequest('snmpv3_authpassphrase', ''),
-		'snmpv3_privprotocol' => getRequest('snmpv3_privprotocol', ITEM_PRIVPROTOCOL_DES),
-		'snmpv3_privpassphrase' => getRequest('snmpv3_privpassphrase', ''),
 		'ipmi_sensor' => getRequest('ipmi_sensor', ''),
 		'authtype' => getRequest('authtype', 0),
 		'username' => getRequest('username', ''),
@@ -870,6 +832,15 @@ function getItemFormData(array $item = [], array $options = []) {
 		'preprocessing_script_maxlength' => DB::getFieldLength('item_preproc', 'params')
 	];
 
+	if ($data['parent_discoveryid'] != 0) {
+		$data['discover'] = hasRequest('form_refresh')
+			? getRequest('discover', DB::getDefault('items', 'discover'))
+			: ($item
+				? $item['discover']
+				: DB::getDefault('items', 'discover')
+			);
+	}
+
 	if ($data['type'] == ITEM_TYPE_HTTPAGENT) {
 		foreach (['query_fields', 'headers'] as $property) {
 			$values = [];
@@ -940,6 +911,7 @@ function getItemFormData(array $item = [], array $options = []) {
 		$data['item'] = $item;
 		$data['hostid'] = !empty($data['hostid']) ? $data['hostid'] : $data['item']['hostid'];
 		$data['limited'] = ($data['item']['templateid'] != 0);
+		$data['interfaceid'] = $item['interfaceid'];
 
 		// discovery rule
 		if ($data['is_discovery_rule']) {
@@ -988,24 +960,13 @@ function getItemFormData(array $item = [], array $options = []) {
 		$data['key'] = $data['item']['key_'];
 		$data['interfaceid'] = $data['item']['interfaceid'];
 		$data['type'] = $data['item']['type'];
-		if ($data['item']['snmp_community'] !== '') {
-			$data['snmp_community'] = $data['item']['snmp_community'];
-		}
 		$data['snmp_oid'] = $data['item']['snmp_oid'];
-		$data['port'] = $data['item']['port'];
 		$data['value_type'] = $data['item']['value_type'];
 		$data['trapper_hosts'] = $data['item']['trapper_hosts'];
 		$data['units'] = $data['item']['units'];
 		$data['valuemapid'] = $data['item']['valuemapid'];
 		$data['hostid'] = $data['item']['hostid'];
 		$data['params'] = $data['item']['params'];
-		$data['snmpv3_contextname'] = $data['item']['snmpv3_contextname'];
-		$data['snmpv3_securityname'] = $data['item']['snmpv3_securityname'];
-		$data['snmpv3_securitylevel'] = $data['item']['snmpv3_securitylevel'];
-		$data['snmpv3_authprotocol'] = $data['item']['snmpv3_authprotocol'];
-		$data['snmpv3_authpassphrase'] = $data['item']['snmpv3_authpassphrase'];
-		$data['snmpv3_privprotocol'] = $data['item']['snmpv3_privprotocol'];
-		$data['snmpv3_privpassphrase'] = $data['item']['snmpv3_privpassphrase'];
 		$data['ipmi_sensor'] = $data['item']['ipmi_sensor'];
 		$data['authtype'] = $data['item']['authtype'];
 		$data['username'] = $data['item']['username'];
@@ -1196,17 +1157,6 @@ function getItemFormData(array $item = [], array $options = []) {
 		$data['alreadyPopulated'] = zbx_toHash($data['alreadyPopulated'], 'inventory_link');
 	}
 
-	// unset snmpv3 fields
-	if ($data['type'] != ITEM_TYPE_SNMPV3) {
-		$data['snmpv3_contextname'] = '';
-		$data['snmpv3_securityname'] = '';
-		$data['snmpv3_securitylevel'] = ITEM_SNMPV3_SECURITYLEVEL_NOAUTHNOPRIV;
-		$data['snmpv3_authprotocol'] = ITEM_AUTHPROTOCOL_MD5;
-		$data['snmpv3_authpassphrase'] = '';
-		$data['snmpv3_privprotocol'] = ITEM_PRIVPROTOCOL_DES;
-		$data['snmpv3_privpassphrase'] = '';
-	}
-
 	// unset ssh auth fields
 	if ($data['type'] != ITEM_TYPE_SSH) {
 		$data['authtype'] = ITEM_AUTHTYPE_PASSWORD;
@@ -1389,6 +1339,13 @@ function getItemPreprocessing(CForm $form, array $preprocessing, $readonly, arra
 						->setReadonly($readonly)
 				];
 				break;
+
+			case ZBX_PREPROC_STR_REPLACE:
+				$params = [
+					$step_param_0->setAttribute('placeholder', _('search string')),
+					$step_param_1->setAttribute('placeholder', _('replacement'))
+				];
+				break;
 		}
 
 		// Create checkbox "Custom on fail" and enable or disable depending on preprocessing type.
@@ -1401,6 +1358,7 @@ function getItemPreprocessing(CForm $form, array $preprocessing, $readonly, arra
 			case ZBX_PREPROC_THROTTLE_VALUE:
 			case ZBX_PREPROC_THROTTLE_TIMED_VALUE:
 			case ZBX_PREPROC_SCRIPT:
+			case ZBX_PREPROC_STR_REPLACE:
 				$on_fail->setEnabled(false);
 				break;
 
@@ -1559,6 +1517,7 @@ function getTriggerMassupdateFormData() {
 		'visible' => getRequest('visible', []),
 		'dependencies' => getRequest('dependencies', []),
 		'tags' => getRequest('tags', []),
+		'mass_update_tags' => getRequest('mass_update_tags', ZBX_ACTION_ADD),
 		'manual_close' => getRequest('manual_close', ZBX_TRIGGER_MANUAL_CLOSE_NOT_ALLOWED),
 		'massupdate' => getRequest('massupdate', 1),
 		'parent_discoveryid' => getRequest('parent_discoveryid'),
@@ -1768,18 +1727,6 @@ function getTriggerFormData(array $data) {
 		CArrayHelper::sort($data['tags'], ['tag', 'value']);
 	}
 
-	if ($data['hostid'] && (!array_key_exists('groupid', $data) || !$data['groupid'])) {
-		$db_hostgroups = API::HostGroup()->get([
-			'output' => ['groupid'],
-			'hostids' => $data['hostid'],
-			'templateids' => $data['hostid']
-		]);
-
-		if ($db_hostgroups) {
-			$data['groupid'] = $db_hostgroups[0]['groupid'];
-		}
-	}
-
 	if ((!empty($data['triggerid']) && !isset($_REQUEST['form_refresh'])) || $data['limited']) {
 		$data['expression'] = $trigger['expression'];
 		$data['recovery_expression'] = $trigger['recovery_expression'];
@@ -1796,6 +1743,7 @@ function getTriggerFormData(array $data) {
 			$data['status'] = $trigger['status'];
 			$data['comments'] = $trigger['comments'];
 			$data['url'] = $trigger['url'];
+			$data['discover'] = $trigger['discover'];
 
 			$db_triggers = DBselect(
 				'SELECT t.triggerid,t.description'.
@@ -1955,381 +1903,6 @@ function getTriggerFormData(array $data) {
 	return $data;
 }
 
-/**
- * Get "Maintenance period" form.
- *
- * @param array        $data                  Current maintenance period data.
- * @param string|array $data[new_timeperiod]  Data of new time period in array or string type indicator that form has
- *                                            been opened with default data.
- *
- * @return CFormList
- */
-function getTimeperiodForm(array $data) {
-	$form = new CFormList();
-
-	$new_timeperiod = $data['new_timeperiod'];
-
-	if (is_array($new_timeperiod)) {
-		if (isset($new_timeperiod['id'])) {
-			$form->addItem(new CVar('new_timeperiod[id]', $new_timeperiod['id']));
-		}
-		if (isset($new_timeperiod['timeperiodid'])) {
-			$form->addItem(new CVar('new_timeperiod[timeperiodid]', $new_timeperiod['timeperiodid']));
-		}
-	}
-	if (!is_array($new_timeperiod)) {
-		$new_timeperiod = [];
-		$new_timeperiod['timeperiod_type'] = TIMEPERIOD_TYPE_ONETIME;
-	}
-	if (!isset($new_timeperiod['every'])) {
-		$new_timeperiod['every'] = 1;
-	}
-	if (!isset($new_timeperiod['day'])) {
-		$new_timeperiod['day'] = 1;
-	}
-	if (!isset($new_timeperiod['hour'])) {
-		$new_timeperiod['hour'] = 12;
-	}
-	if (!isset($new_timeperiod['minute'])) {
-		$new_timeperiod['minute'] = 0;
-	}
-	if (!isset($new_timeperiod['period_days'])) {
-		$new_timeperiod['period_days'] = 0;
-	}
-	if (!isset($new_timeperiod['period_hours'])) {
-		$new_timeperiod['period_hours'] = 1;
-	}
-	if (!isset($new_timeperiod['period_minutes'])) {
-		$new_timeperiod['period_minutes'] = 0;
-	}
-	if (!isset($new_timeperiod['month_date_type'])) {
-		$new_timeperiod['month_date_type'] = !(bool)$new_timeperiod['day'];
-	}
-
-	// start time
-	if (isset($new_timeperiod['start_time'])) {
-		$new_timeperiod['hour'] = floor($new_timeperiod['start_time'] / SEC_PER_HOUR);
-		$new_timeperiod['minute'] = floor(($new_timeperiod['start_time'] - ($new_timeperiod['hour'] * SEC_PER_HOUR)) / SEC_PER_MIN);
-	}
-
-	// period
-	if (isset($new_timeperiod['period'])) {
-		$new_timeperiod['period_days'] = floor($new_timeperiod['period'] / SEC_PER_DAY);
-		$new_timeperiod['period_hours'] = floor(($new_timeperiod['period'] - ($new_timeperiod['period_days'] * SEC_PER_DAY)) / SEC_PER_HOUR);
-		$new_timeperiod['period_minutes'] = floor(($new_timeperiod['period'] - $new_timeperiod['period_days'] * SEC_PER_DAY - $new_timeperiod['period_hours'] * SEC_PER_HOUR) / SEC_PER_MIN);
-	}
-
-	// daysofweek
-	$dayofweek = '';
-	$dayofweek .= !isset($new_timeperiod['dayofweek_mo']) ? '0' : '1';
-	$dayofweek .= !isset($new_timeperiod['dayofweek_tu']) ? '0' : '1';
-	$dayofweek .= !isset($new_timeperiod['dayofweek_we']) ? '0' : '1';
-	$dayofweek .= !isset($new_timeperiod['dayofweek_th']) ? '0' : '1';
-	$dayofweek .= !isset($new_timeperiod['dayofweek_fr']) ? '0' : '1';
-	$dayofweek .= !isset($new_timeperiod['dayofweek_sa']) ? '0' : '1';
-	$dayofweek .= !isset($new_timeperiod['dayofweek_su']) ? '0' : '1';
-	if (isset($new_timeperiod['dayofweek'])) {
-		$dayofweek = zbx_num2bitstr($new_timeperiod['dayofweek'], true);
-	}
-
-	$new_timeperiod['dayofweek_mo'] = $dayofweek[0];
-	$new_timeperiod['dayofweek_tu'] = $dayofweek[1];
-	$new_timeperiod['dayofweek_we'] = $dayofweek[2];
-	$new_timeperiod['dayofweek_th'] = $dayofweek[3];
-	$new_timeperiod['dayofweek_fr'] = $dayofweek[4];
-	$new_timeperiod['dayofweek_sa'] = $dayofweek[5];
-	$new_timeperiod['dayofweek_su'] = $dayofweek[6];
-
-	// months
-	$month = '';
-	$month .= !isset($new_timeperiod['month_jan']) ? '0' : '1';
-	$month .= !isset($new_timeperiod['month_feb']) ? '0' : '1';
-	$month .= !isset($new_timeperiod['month_mar']) ? '0' : '1';
-	$month .= !isset($new_timeperiod['month_apr']) ? '0' : '1';
-	$month .= !isset($new_timeperiod['month_may']) ? '0' : '1';
-	$month .= !isset($new_timeperiod['month_jun']) ? '0' : '1';
-	$month .= !isset($new_timeperiod['month_jul']) ? '0' : '1';
-	$month .= !isset($new_timeperiod['month_aug']) ? '0' : '1';
-	$month .= !isset($new_timeperiod['month_sep']) ? '0' : '1';
-	$month .= !isset($new_timeperiod['month_oct']) ? '0' : '1';
-	$month .= !isset($new_timeperiod['month_nov']) ? '0' : '1';
-	$month .= !isset($new_timeperiod['month_dec']) ? '0' : '1';
-	if (isset($new_timeperiod['month'])) {
-		$month = zbx_num2bitstr($new_timeperiod['month'], true);
-	}
-
-	$new_timeperiod['month_jan'] = $month[0];
-	$new_timeperiod['month_feb'] = $month[1];
-	$new_timeperiod['month_mar'] = $month[2];
-	$new_timeperiod['month_apr'] = $month[3];
-	$new_timeperiod['month_may'] = $month[4];
-	$new_timeperiod['month_jun'] = $month[5];
-	$new_timeperiod['month_jul'] = $month[6];
-	$new_timeperiod['month_aug'] = $month[7];
-	$new_timeperiod['month_sep'] = $month[8];
-	$new_timeperiod['month_oct'] = $month[9];
-	$new_timeperiod['month_nov'] = $month[10];
-	$new_timeperiod['month_dec'] = $month[11];
-
-	$bit_dayofweek = strrev($dayofweek);
-	$bit_month = strrev($month);
-
-	$form->addRow(
-		(new Clabel(_('Period type'), 'new_timeperiod[timeperiod_type]')),
-		(new CComboBox('new_timeperiod[timeperiod_type]', $new_timeperiod['timeperiod_type'], 'submit()', [
-			TIMEPERIOD_TYPE_ONETIME => _('One time only'),
-			TIMEPERIOD_TYPE_DAILY	=> _('Daily'),
-			TIMEPERIOD_TYPE_WEEKLY	=> _('Weekly'),
-			TIMEPERIOD_TYPE_MONTHLY	=> _('Monthly')
-		]))
-	);
-
-	if ($new_timeperiod['timeperiod_type'] == TIMEPERIOD_TYPE_DAILY) {
-		$form
-			->addItem(new CVar('new_timeperiod[dayofweek]', bindec($bit_dayofweek)))
-			->addItem(new CVar('new_timeperiod[month]', bindec($bit_month)))
-			->addItem(new CVar('new_timeperiod[day]', $new_timeperiod['day']))
-			->addItem(new CVar('new_timeperiod[start_date]', $new_timeperiod['start_date']))
-			->addItem(new CVar('new_timeperiod[month_date_type]', $new_timeperiod['month_date_type']))
-			->addRow(
-				(new CLabel(_('Every day(s)'), 'new_timeperiod[every]'))->setAsteriskMark(),
-				(new CNumericBox('new_timeperiod[every]', $new_timeperiod['every'], 3))
-					->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
-					->setAriaRequired()
-			);
-	}
-	elseif ($new_timeperiod['timeperiod_type'] == TIMEPERIOD_TYPE_WEEKLY) {
-		$form
-			->addItem(new CVar('new_timeperiod[month]', bindec($bit_month)))
-			->addItem(new CVar('new_timeperiod[day]', $new_timeperiod['day']))
-			->addItem(new CVar('new_timeperiod[start_date]', $new_timeperiod['start_date']))
-			->addItem(new CVar('new_timeperiod[month_date_type]', $new_timeperiod['month_date_type']))
-			->addRow(
-				(new CLabel(_('Every week(s)'), 'new_timeperiod[every]'))->setAsteriskMark(),
-				(new CNumericBox('new_timeperiod[every]', $new_timeperiod['every'], 2))
-					->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
-					->setAriaRequired()
-			)
-			->addRow(
-				(new CLabel(_('Day of week'), 'new_timeperiod_dayofweek'))->setAsteriskMark(),
-				(new CTable())
-					->addRow(
-						(new CCheckBox('new_timeperiod[dayofweek_mo]'))
-							->setLabel(_('Monday'))
-							->setChecked($dayofweek[0] == 1)
-					)
-					->addRow(
-						(new CCheckBox('new_timeperiod[dayofweek_tu]'))
-							->setLabel(_('Tuesday'))
-							->setChecked($dayofweek[1] == 1)
-					)
-					->addRow(
-						(new CCheckBox('new_timeperiod[dayofweek_we]'))
-							->setLabel(_('Wednesday'))
-							->setChecked($dayofweek[2] == 1)
-					)
-					->addRow(
-						(new CCheckBox('new_timeperiod[dayofweek_th]'))
-							->setLabel(_('Thursday'))
-							->setChecked($dayofweek[3] == 1)
-					)
-					->addRow(
-						(new CCheckBox('new_timeperiod[dayofweek_fr]'))
-							->setLabel(_('Friday'))
-							->setChecked($dayofweek[4] == 1)
-					)
-					->addRow(
-						(new CCheckBox('new_timeperiod[dayofweek_sa]'))
-							->setLabel(_('Saturday'))
-							->setChecked($dayofweek[5] == 1)
-					)
-					->addRow(
-						(new CCheckBox('new_timeperiod[dayofweek_su]'))
-							->setLabel(_('Sunday'))
-							->setChecked($dayofweek[6] == 1)
-					)
-					->setId('new_timeperiod_dayofweek')
-			);
-	}
-	elseif ($new_timeperiod['timeperiod_type'] == TIMEPERIOD_TYPE_MONTHLY) {
-		$form
-			->addItem(new CVar('new_timeperiod[start_date]', $new_timeperiod['start_date']))
-			->addRow(
-				(new CLabel(_('Month'), 'new_timeperiod_month'))->setAsteriskMark(),
-				(new CTable())
-					->addRow([
-						(new CCheckBox('new_timeperiod[month_jan]'))
-							->setLabel(_('January'))
-							->setChecked($month[0] == 1),
-						(new CCheckBox('new_timeperiod[month_jul]'))
-							->setLabel(_('July'))
-							->setChecked($month[6] == 1)
-					])
-					->addRow([
-						(new CCheckBox('new_timeperiod[month_feb]'))
-							->setLabel(_('February'))
-							->setChecked($month[1] == 1),
-						(new CCheckBox('new_timeperiod[month_aug]'))
-							->setLabel(_('August'))
-							->setChecked($month[7] == 1)
-					])
-					->addRow([
-						(new CCheckBox('new_timeperiod[month_mar]'))
-							->setLabel(_('March'))
-							->setChecked($month[2] == 1),
-						(new CCheckBox('new_timeperiod[month_sep]'))
-							->setLabel(_('September'))
-							->setChecked($month[8] == 1)
-					])
-					->addRow([
-						(new CCheckBox('new_timeperiod[month_apr]'))
-							->setLabel(_('April'))
-							->setChecked($month[3] == 1),
-						(new CCheckBox('new_timeperiod[month_oct]'))
-							->setLabel(_('October'))
-							->setChecked($month[9] == 1)
-					])
-					->addRow([
-						(new CCheckBox('new_timeperiod[month_may]'))
-							->setLabel(_('May'))
-							->setChecked($month[4] == 1),
-						(new CCheckBox('new_timeperiod[month_nov]'))
-							->setLabel(_('November'))
-							->setChecked($month[10] == 1)
-					])
-					->addRow([
-						(new CCheckBox('new_timeperiod[month_jun]'))
-							->setLabel(_('June'))
-							->setChecked($month[5] == 1),
-						(new CCheckBox('new_timeperiod[month_dec]'))
-							->setLabel(_('December'))
-							->setChecked($month[11] == 1)
-					])
-					->setId('new_timeperiod_month')
-			)
-			->addRow(_('Date'),
-				(new CRadioButtonList('new_timeperiod[month_date_type]', (int) $new_timeperiod['month_date_type']))
-					->addValue(_('Day of month'), 0, null, 'submit()')
-					->addValue(_('Day of week'), 1, null, 'submit()')
-					->setModern(true)
-			);
-
-		if ($new_timeperiod['month_date_type'] > 0) {
-			$form
-				->addItem(new CVar('new_timeperiod[day]', $new_timeperiod['day']))
-				->addRow(
-					(new CLabel(_('Day of week'), 'new_timeperiod_dayofweek'))->setAsteriskMark(),
-					(new CTable())
-						->addRow((new CCol(new CComboBox('new_timeperiod[every]', $new_timeperiod['every'], null, [
-								1 => _('first'),
-								2 => _x('second', 'adjective'),
-								3 => _('third'),
-								4 => _('fourth'),
-								5 => _('last')
-							])))
-						)
-						->addRow(
-							(new CCheckBox('new_timeperiod[dayofweek_mo]'))
-								->setLabel(_('Monday'))
-								->setChecked($dayofweek[0] == 1)
-						)
-						->addRow(
-							(new CCheckBox('new_timeperiod[dayofweek_tu]'))
-								->setLabel(_('Tuesday'))
-								->setChecked($dayofweek[1] == 1)
-						)
-						->addRow(
-							(new CCheckBox('new_timeperiod[dayofweek_we]'))
-								->setLabel(_('Wednesday'))
-								->setChecked($dayofweek[2] == 1)
-						)
-						->addRow(
-							(new CCheckBox('new_timeperiod[dayofweek_th]'))
-								->setLabel(_('Thursday'))
-								->setChecked($dayofweek[3] == 1)
-						)
-						->addRow(
-							(new CCheckBox('new_timeperiod[dayofweek_fr]'))
-								->setLabel(_('Friday'))
-								->setChecked($dayofweek[4] == 1)
-						)
-						->addRow(
-							(new CCheckBox('new_timeperiod[dayofweek_sa]'))
-								->setLabel(_('Saturday'))
-								->setChecked($dayofweek[5] == 1)
-						)
-						->addRow(
-							(new CCheckBox('new_timeperiod[dayofweek_su]'))
-								->setLabel(_('Sunday'))
-								->setChecked($dayofweek[6] == 1)
-						)
-						->setId('new_timeperiod_dayofweek')
-				);
-		}
-		else {
-			$form
-				->addItem(new CVar('new_timeperiod[dayofweek]', bindec($bit_dayofweek)))
-				->addRow(
-					(new CLabel(_('Day of month'), 'new_timeperiod[day]'))->setAsteriskMark(),
-					(new CNumericBox('new_timeperiod[day]', $new_timeperiod['day'], 2))
-						->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
-						->setAriaRequired()
-				);
-		}
-	}
-	else {
-		$form
-			->addItem(new CVar('new_timeperiod[every]', $new_timeperiod['every'], 'new_timeperiod_every_tmp'))
-			->addItem(new CVar('new_timeperiod[month]', bindec($bit_month), 'new_timeperiod_month_tmp'))
-			->addItem(new CVar('new_timeperiod[day]', $new_timeperiod['day'], 'new_timeperiod_day_tmp'))
-			->addItem(new CVar('new_timeperiod[hour]', $new_timeperiod['hour'], 'new_timeperiod_hour_tmp'))
-			->addItem(new CVar('new_timeperiod[minute]', $new_timeperiod['minute'], 'new_timeperiod_minute_tmp'))
-			->addItem(new CVar('new_timeperiod[month_date_type]', $new_timeperiod['month_date_type']))
-			->addItem(new CVar('new_timeperiod[dayofweek]', bindec($bit_dayofweek)));
-
-		$new_timeperiod['start_date'] = ($data['new_timeperiod_start_date'] === null)
-			? date(ZBX_DATE_TIME, time())
-			: $data['new_timeperiod_start_date'];
-
-		$form->addRow(
-			(new CLabel(_('Date'), 'new_timeperiod_start_date'))->setAsteriskMark(),
-			(new CDateSelector('new_timeperiod_start_date', $new_timeperiod['start_date']))
-				->setDateFormat(ZBX_DATE_TIME)
-				->setPlaceholder(_('YYYY-MM-DD hh:mm'))
-				->setAriaRequired()
-		);
-	}
-
-	if ($new_timeperiod['timeperiod_type'] != TIMEPERIOD_TYPE_ONETIME) {
-		$form->addRow(_('At (hour:minute)'), [
-			(new CNumericBox('new_timeperiod[hour]', $new_timeperiod['hour'], 2))
-				->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH),
-			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-			':',
-			(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
-			(new CNumericBox('new_timeperiod[minute]', $new_timeperiod['minute'], 2))
-				->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
-		]);
-	}
-
-	$perHours = new CComboBox('new_timeperiod[period_hours]', $new_timeperiod['period_hours'], null, range(0, 23));
-	$perMinutes = new CComboBox('new_timeperiod[period_minutes]', $new_timeperiod['period_minutes'], null, range(0, 59));
-	$form->addRow(
-		(new CLabel(_('Maintenance period length'), 'new_timeperiod'))->setAsteriskMark(),
-		(new CDiv([
-			(new CNumericBox('new_timeperiod[period_days]', $new_timeperiod['period_days'], 3))
-				->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH),
-			_('Days').SPACE.SPACE,
-			$perHours,
-			_('Hours').SPACE.SPACE,
-			$perMinutes,
-			_('Minutes')
-		]))->setId('new_timeperiod')
-	);
-
-	return $form;
-}
-
 /**
  * Renders tag table row.
  *
@@ -2341,20 +1914,23 @@ function getTimeperiodForm(array $data) {
  * @return CRow
  */
 function renderTagTableRow($index, $tag = '', $value = '', array $options = []) {
-	$options = array_merge(['readonly' => false], $options);
+	$options = array_merge([
+		'readonly' => false,
+		'field_name' => 'tags'
+	], $options);
 
 	return (new CRow([
 		(new CCol(
-			(new CTextAreaFlexible('tags['.$index.'][tag]', $tag, $options))
+			(new CTextAreaFlexible($options['field_name'].'['.$index.'][tag]', $tag, $options))
 				->setWidth(ZBX_TEXTAREA_TAG_WIDTH)
 				->setAttribute('placeholder', _('tag'))
 		))->addClass(ZBX_STYLE_TEXTAREA_FLEXIBLE_PARENT),
 		(new CCol(
-			(new CTextAreaFlexible('tags['.$index.'][value]', $value, $options))
+			(new CTextAreaFlexible($options['field_name'].'['.$index.'][value]', $value, $options))
 				->setWidth(ZBX_TEXTAREA_TAG_VALUE_WIDTH)
 				->setAttribute('placeholder', _('value'))
 		))->addClass(ZBX_STYLE_TEXTAREA_FLEXIBLE_PARENT),
-		(new CButton('tags['.$index.'][remove]', _('Remove')))
+		(new CButton($options['field_name'].'['.$index.'][remove]', _('Remove')))
 			->addClass(ZBX_STYLE_BTN_LINK)
 			->addClass('element-table-remove')
 			->setEnabled(!$options['readonly'])
@@ -2371,11 +1947,17 @@ function renderTagTableRow($index, $tag = '', $value = '', array $options = [])
  *
  * @return CTable
  */
-function renderTagTable(array $tags, $readonly = false) {
+function renderTagTable(array $tags, $readonly = false, array $options = []) {
 	$table = (new CTable())->addClass(ZBX_STYLE_TEXTAREA_FLEXIBLE_CONTAINER);
 
+	$row_options = ['readonly' => $readonly];
+
+	if (array_key_exists('field_name', $options)) {
+		$row_options['field_name'] = $options['field_name'];
+	}
+
 	foreach ($tags as $index => $tag) {
-		$table->addRow(renderTagTableRow($index, $tag['tag'], $tag['value'], ['readonly' => $readonly]));
+		$table->addRow(renderTagTableRow($index, $tag['tag'], $tag['value'], $row_options));
 	}
 
 	return $table->setFooter(new CCol(
