@@ -19,6 +19,10 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 require_once dirname(__FILE__).'/js/configuration.triggers.edit.js.php';
 
 $triggersWidget = (new CWidget())
@@ -89,14 +93,13 @@ $popup_options = [
 	'dstfld1' => $data['expression_field_name'],
 	'parent_discoveryid' => $data['parent_discoveryid']
 ];
-if ($data['groupid'] && $data['hostid']) {
-	$popup_options['groupid'] = $data['groupid'];
+if ($data['hostid']) {
 	$popup_options['hostid'] = $data['hostid'];
 }
 $add_expression_button = (new CButton('insert', ($data['expression_constructor'] == IM_TREE) ? _('Edit') : _('Add')))
 	->addClass(ZBX_STYLE_BTN_GREY)
 	->onClick('return PopUp("popup.triggerexpr",jQuery.extend('.
-		CJs::encodeJson($popup_options).
+		json_encode($popup_options).
 			',{expression: jQuery(\'[name="'.$data['expression_field_name'].'"]\').val()}), null, this);'
 	)
 	->removeId();
@@ -223,13 +226,13 @@ if ($data['expression_constructor'] == IM_TREE) {
 							->setChecked($i == 0)
 							->onClick('check_target(this, '.TRIGGER_EXPRESSION.');')
 						: null,
-					$e['list'],
+					(new CDiv($e['list']))->addClass(ZBX_STYLE_WORDWRAP),
 					!$data['limited']
 						? (new CCol(
 							(new CSimpleButton(_('Remove')))
 								->addClass(ZBX_STYLE_BTN_LINK)
 								->onClick('javascript:'.
-									' if (confirm('.CJs::encodeJson(_('Delete expression?')).')) {'.
+									' if (confirm('.json_encode(_('Delete expression?')).')) {'.
 										' delete_expression("'.$e['id'] .'", '.TRIGGER_EXPRESSION.');'.
 										' document.forms["'.$triggersForm->getName().'"].submit();'.
 									' }'
@@ -291,7 +294,7 @@ $add_recovery_expression_button = (new CButton('insert',
 	)
 	->addClass(ZBX_STYLE_BTN_GREY)
 	->onClick('return PopUp("popup.triggerexpr",jQuery.extend('.
-		CJs::encodeJson([
+		json_encode([
 			'srctbl' => $data['recovery_expression_field_name'],
 			'srcfld1' => $data['recovery_expression_field_name'],
 			'dstfrm' => $triggersForm->getName(),
@@ -425,7 +428,7 @@ if ($data['recovery_expression_constructor'] == IM_TREE) {
 							(new CSimpleButton(_('Remove')))
 								->addClass(ZBX_STYLE_BTN_LINK)
 								->onClick('javascript:'.
-									' if (confirm('.CJs::encodeJson(_('Delete expression?')).')) {'.
+									' if (confirm('.json_encode(_('Delete expression?')).')) {'.
 										' delete_expression("'.$e['id'] .'", '.TRIGGER_RECOVERY_EXPRESSION.');'.
 										' document.forms["'.$triggersForm->getName().'"].submit();'.
 									' }'
@@ -518,7 +521,12 @@ $triggersFormList
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			->setMaxlength(DB::getFieldLength('triggers', 'comments'))
 	)
-	->addRow(_('Create enabled'), (new CCheckBox('status'))->setChecked($status));
+	->addRow(_('Create enabled'), (new CCheckBox('status'))->setChecked($status))
+	->addRow(_('Discover'),
+		(new CCheckBox('discover', ZBX_PROTOTYPE_DISCOVER))
+			->setChecked($data['discover'] == ZBX_PROTOTYPE_DISCOVER)
+			->setUncheckedValue(ZBX_PROTOTYPE_NO_DISCOVER)
+	);
 
 // append tabs to form
 $triggersTab = new CTabView();
@@ -527,16 +535,13 @@ if (!$data['form_refresh']) {
 }
 $triggersTab->addTab('triggersTab',	_('Trigger prototype'), $triggersFormList);
 
-/*
- * Tags tab
- */
-$tags_view = new CView('configuration.tags.tab', [
+// tags
+$triggersTab->addTab('tags-tab', _('Tags'), new CPartial('configuration.tags.tab', [
 	'source' => 'trigger_prototype',
 	'tags' => $data['tags'],
 	'show_inherited_tags' => $data['show_inherited_tags'],
 	'readonly' => false
-]);
-$triggersTab->addTab('tags-tab', _('Tags'), $tags_view->render());
+]));
 
 /*
  * Dependencies tab
@@ -583,7 +588,7 @@ $dependenciesFormList->addRow(_('Dependencies'),
 		new CHorList([
 			(new CButton('add_dep_trigger', _('Add')))
 				->onClick('return PopUp("popup.generic",'.
-					CJs::encodeJson([
+					json_encode([
 						'srctbl' => 'triggers',
 						'srcfld1' => 'triggerid',
 						'reference' => 'deptrigger',
@@ -591,14 +596,13 @@ $dependenciesFormList->addRow(_('Dependencies'),
 						'with_triggers' => '1',
 						'normal_only' => '1',
 						'noempty' => '1',
-						'hostid' => $data['hostid'],
-						'groupid' => $data['groupid']
+						'hostid' => $data['hostid']
 					]).', null, this);'
 				)
 				->addClass(ZBX_STYLE_BTN_LINK),
 			(new CButton('add_dep_trigger_prototype', _('Add prototype')))
 				->onClick('return PopUp("popup.generic",'.
-					CJs::encodeJson([
+					json_encode([
 						'srctbl' => 'trigger_prototypes',
 						'srcfld1' => 'triggerid',
 						'reference' => 'deptrigger',
@@ -644,4 +648,4 @@ $triggersForm->addItem($triggersTab);
 
 $triggersWidget->addItem($triggersForm);
 
-return $triggersWidget;
+$triggersWidget->show();
